/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#ifndef __EV_VIEW_MARSHAL_MARSHAL_H__
#define __EV_VIEW_MARSHAL_MARSHAL_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* VOID:ENUM,ENUM (./ev-view-marshal.list:1) */
G_GNUC_INTERNAL
void ev_view_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:INT,INT (./ev-view-marshal.list:2) */
G_GNUC_INTERNAL
void ev_view_marshal_VOID__INT_INT (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);

/* BOOLEAN:ENUM,INT,BOOLEAN (./ev-view-marshal.list:3) */
G_GNUC_INTERNAL
void ev_view_marshal_BOOLEAN__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);


G_END_DECLS

#endif /* __EV_VIEW_MARSHAL_MARSHAL_H__ */
