#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.ev_previewer"), aligned (sizeof(void *) > 8 ? sizeof(void *) : 8)))
#else
# define SECTION
#endif

static const SECTION union { const guint8 data[645]; const double alignment; void * const ptr;}  ev_previewer_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\344\000\000\000\000\000\000\050\007\000\000\000"
  "\000\000\000\000\001\000\000\000\002\000\000\000\003\000\000\000"
  "\005\000\000\000\006\000\000\000\007\000\000\000\031\047\334\342"
  "\004\000\000\000\344\000\000\000\015\000\166\000\370\000\000\000"
  "\103\002\000\000\113\120\220\013\002\000\000\000\103\002\000\000"
  "\004\000\114\000\110\002\000\000\114\002\000\000\324\265\002\000"
  "\377\377\377\377\114\002\000\000\001\000\114\000\120\002\000\000"
  "\124\002\000\000\254\375\211\161\005\000\000\000\124\002\000\000"
  "\006\000\114\000\134\002\000\000\140\002\000\000\301\104\303\351"
  "\006\000\000\000\140\002\000\000\003\000\114\000\144\002\000\000"
  "\150\002\000\000\201\321\040\031\001\000\000\000\150\002\000\000"
  "\005\000\114\000\160\002\000\000\164\002\000\000\324\045\343\073"
  "\003\000\000\000\164\002\000\000\012\000\114\000\200\002\000\000"
  "\204\002\000\000\160\162\145\166\151\145\167\145\162\056\170\155"
  "\154\000\000\000\000\000\000\000\352\004\000\000\001\000\000\000"
  "\170\332\205\224\137\117\203\060\024\305\337\367\051\010\037\300"
  "\351\073\143\061\213\063\306\250\104\215\113\366\126\331\215\066"
  "\051\275\330\226\155\037\337\376\301\001\345\202\217\234\163\176"
  "\207\333\162\103\266\076\127\042\071\202\322\034\345\052\275\271"
  "\272\116\327\371\042\153\170\236\031\104\361\311\124\042\131\005"
  "\253\264\120\160\344\160\172\017\142\032\154\156\240\152\375\173"
  "\364\011\154\164\301\276\040\115\130\151\174\143\244\057\011\360"
  "\031\316\046\206\056\232\005\064\324\114\061\203\152\014\273\310"
  "\033\010\050\255\333\341\003\165\276\340\303\236\151\313\315\216"
  "\037\314\167\127\060\120\047\241\341\314\175\221\106\366\210\325"
  "\203\034\022\255\066\015\274\064\146\114\070\161\032\171\005\015"
  "\004\024\344\177\356\063\174\345\102\161\331\153\030\250\026\132"
  "\266\253\221\147\254\054\355\075\373\262\266\141\313\005\154\004"
  "\152\330\161\171\300\323\255\013\164\115\221\353\312\306\025\165"
  "\004\325\164\114\106\061\111\307\266\130\206\335\373\333\210\170"
  "\244\330\247\153\012\321\350\210\164\022\035\176\342\162\224\366"
  "\032\035\277\373\151\130\057\031\036\311\344\306\050\341\355\250"
  "\374\242\323\330\143\115\214\037\304\051\200\072\102\253\116\217"
  "\106\276\247\063\346\100\352\175\075\147\016\335\203\102\222\164"
  "\206\337\127\373\073\133\374\002\140\112\276\100\000\050\165\165"
  "\141\171\051\157\162\147\057\000\005\000\000\000\057\000\000\000"
  "\001\000\000\000\141\164\162\151\154\057\000\000\006\000\000\000"
  "\165\151\057\000\000\000\000\000\155\141\164\145\057\000\000\000"
  "\003\000\000\000\160\162\145\166\151\145\167\145\162\057\000\000"
  "\004\000\000\000" };

static GStaticResource static_resource = { ev_previewer_resource_data.data, sizeof (ev_previewer_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *ev_previewer_get_resource (void);
GResource *ev_previewer_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/* GLIB - Library of useful routines for C programming
 * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GLib Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GLib at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_CONSTRUCTOR_H__
#define __G_CONSTRUCTOR_H__

/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER)

/*
 * Only try to include gslist.h if not already included via glib.h,
 * so that items using gconstructor.h outside of GLib (such as
 * GResources) continue to build properly.
 */
#ifndef __G_LIB_H__
#include "gslist.h"
#endif

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */
#endif /* __G_CONSTRUCTOR_H__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(ev_previewerresource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(ev_previewerresource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(ev_previewerresource_destructor)
#endif
G_DEFINE_DESTRUCTOR(ev_previewerresource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void ev_previewerresource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void ev_previewerresource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
